%function [occ_pers_vec, welfare_vec, sorting_vec, u_rate_vec] = decomp(inputfolder)
clear

%% BASELINE
% Now do experiments for Spain and US
for ncal=1:2    %now this does NOT do restricted experiments
    if ncal==1
        %load calibration_results_9occ.mat paramout %old version, n_hc=2, occ=9
        load results/calibration_results_3hc_9occ paramout %new results, 3hc, 9occ
        baseline=paramout;
        load results/calibration_results_Spain.mat
        baseline(1)=paramout;
        kappa_Spain=paramout;
    elseif ncal==2
        %load calibration_results_9occ.mat paramout %old version, n_hc=2, occ=9
        load results/calibration_results_3hc_9occ paramout %new results, 3hc, 9occ
        baseline=paramout;
        load results/calibration_results_US.mat
        baseline(1)=paramout;
        kappa_US=paramout;
    elseif ncal==3
        %load calibration_results_9occ_restricted.mat paramout
        load results/calibration_results_3hc_9occ_restricted.mat paramout
        baseline(1:2)=paramout(1:2);
        baseline(3)=0;
        baseline(4)=paramout(3);
        baseline(5)=1/9;
        baseline(6:12)=paramout(4:10);
        load results/calibration_results_Spain_restricted.mat
        baseline(1)=paramout;
        kappa_Spain_restricted=paramout;
    elseif ncal==4
        %load calibration_results_9occ_restricted.mat paramout
        load results/calibration_results_3hc_9occ_restricted.mat paramout
        baseline(1:2)=paramout(1:2);
        baseline(3)=0;
        baseline(4)=paramout(3);
        baseline(5)=1/9;
        baseline(6:12)=paramout(4:10);
        load results/calibration_results_US_restricted.mat
        baseline(1)=paramout;
        kappa_US_restricted=paramout;
    end
    
    if ncal<3
    %Experiments one after the other
    for nexp = 1:4
        if nexp == 1, param=baseline; %baseline case
        elseif nexp == 2
            %% COUNTERFACTUAL 1 (NO JF PREMIUM)
            param = baseline;
            param(3)=0;
        elseif nexp == 3
            %% COUNTERFACTUAL 2 (NO COMP.ADV. TRANSMISSION)
            param = baseline;
            param(4)=1/n_occ;
        elseif nexp == 4
            %% COUNTERFACTUAL 3 (NO PREF. TRANSMISSION)
            param = baseline;
            param(5)=1/n_occ;
        end
        write_parameters(param);
        model_sons();
        compute_all_statistics;
        load('base_cal/statistics_exper.mat');

        %Here we define different variables for each experiment
        if nexp == 1, sort_base= [share_net'; share_adv'; share_pref']; end
        occ_pers_vec(nexp)=occ_pers;
        welfare_vec(nexp)=welfare;
        total_output_vec(nexp)=total_output;
        sorting_adv_son_vec(nexp)=sorting_adv;
        sorting_pref_son_vec(nexp)=sorting_pref;
        sorting_adv_fat_vec(nexp)=sorting_adv_fat;
        sorting_pref_fat_vec(nexp)=sorting_pref_fat;
        output_per_work_vec(nexp)=output_per_work;
        wage_variance_vec(nexp)=wage_variance;
        welfare_variance_vec(nexp)=CV_welfare;
        u_rate_vec(nexp)=u_rate;
        avg_JF_vec(nexp)=avg_JF;
        avg_JS_vec(nexp)=avg_JS;
        theta_vec(nexp)=max(theta);
    end
    
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    
    occ_pers_vec_rel_change(2:4)= 100*(occ_pers_vec(2:4)-occ_pers_vec(1))/(occ_pers_vec(1)-1);
    welfare_vec_rel_change(2:4)= 100*(welfare_vec(2:4)-welfare_vec(1))/(welfare_vec(1));
    output_rel_change(2:4)=(total_output_vec(2:4)-total_output_vec(1))/total_output_vec(1);
    output_per_work_vec_rel_change(2:4)=100*(output_per_work_vec(2:4)-output_per_work_vec(1))/(output_per_work_vec(1));
    output_per_work_vec_rel_change(1)=output_per_work_vec(1);
    wage_variance_vec_rel_change(2:4)=100*(wage_variance_vec(2:4)-wage_variance_vec(1))/(wage_variance_vec(1));
    wage_variance_vec_rel_change(1)=wage_variance_vec(1);
    welfare_variance_vec_rel_change(2:4)=100*(welfare_variance_vec(2:4)-welfare_variance_vec(1))/(welfare_variance_vec(1));
    welfare_variance_vec_rel_change(1)=welfare_variance_vec(1);
    u_rate_vec_rel_change(2:4)=100*(u_rate_vec(2:4)-u_rate_vec(1))/(u_rate_vec(1));
    u_rate_vec_rel_change(1)=u_rate_vec(1);
    avg_JF_vec_rel_change(2:4)=100*(avg_JF_vec(2:4)-avg_JF_vec(1))/(avg_JF_vec(1));
    avg_JF_vec_rel_change(1)=avg_JF_vec(1);
    avg_JS_vec_rel_change(2:4)=100*(avg_JS_vec(2:4)-avg_JS_vec(1))/(avg_JS_vec(1));
    avg_JS_vec_rel_change(1)=avg_JS_vec(1);
    theta_vec_rel_change(2:4)=100*(theta_vec(2:4)-theta_vec(1))/(theta_vec(1));
    theta_vec_rel_change(1)=theta_vec(1);
    
    fprintf('Decomposition')
    exper = [occ_pers_vec; occ_pers_vec_rel_change; ...
        %welfare_vec;
        welfare_vec_rel_change; output_rel_change;...
        sorting_adv_son_vec; sorting_pref_son_vec; ...
        sorting_adv_fat_vec; sorting_pref_fat_vec; ...
        output_per_work_vec_rel_change; wage_variance_vec_rel_change; ...
        welfare_variance_vec_rel_change; u_rate_vec_rel_change; ...
        avg_JF_vec_rel_change; avg_JS_vec_rel_change; ...
        theta_vec_rel_change]
    
    else
        for nexp = 1:2
        if nexp == 1, param=baseline; %baseline case
        elseif nexp == 2
            %% COUNTERFACTUAL 1 (NO COMP.ADV. TRANSMISSION)
            param = baseline;
            param(4)=1/n_occ;
        end
        write_parameters_SPARSE_NEW_STATE_WITH_SONS(param);
        model_sons_JOINT_NEW_STATE();
        compute_all_statistics;
        load('base_cal/statistics_exper.mat');
        
                %Here it defines different variables for each experiment
        if nexp == 1, sort_base_restricted= [share_net'; share_adv'; share_pref']; end
        occ_pers_vec_restricted(nexp)=occ_pers;
        welfare_vec_restricted(nexp)=welfare;
        total_output_vec_restricted(nexp)=total_output;
        sorting_adv_son_vec_restricted(nexp)=sorting_adv;
        sorting_pref_son_vec_restricted(nexp)=sorting_pref;
        sorting_adv_fat_vec_restricted(nexp)=sorting_adv_fat;
        sorting_pref_fat_vec_restricted(nexp)=sorting_pref_fat;
        output_per_work_vec_restricted(nexp)=output_per_work;
        wage_variance_vec_restricted(nexp)=wage_variance;
        welfare_variance_vec_restricted(nexp)=CV_welfare;
        u_rate_vec_restricted(nexp)=u_rate;
        avg_JF_vec_restricted(nexp)=avg_JF;
        avg_JS_vec_restricted(nexp)=avg_JS;
        theta_vec_restricted(nexp)=max(theta);
        end
        
    occ_pers_vec_rel_change_restricted(2)= 100*(occ_pers_vec_restricted(2)-occ_pers_vec_restricted(1))/(occ_pers_vec_restricted(1)-1);
    welfare_vec_rel_change_restricted(2)= 100*(welfare_vec_restricted(2)-welfare_vec_restricted(1))/(welfare_vec_restricted(1));
    output_rel_change_restricted(2)=(total_output_vec_restricted(2)-total_output_vec_restricted(1))/total_output_vec_restricted(1);
    output_per_work_vec_rel_change_restricted(2)=100*(output_per_work_vec_restricted(2)-output_per_work_vec_restricted(1))/(output_per_work_vec_restricted(1));
    output_per_work_vec_rel_change_restricted(1)=output_per_work_vec_restricted(1);
    wage_variance_vec_rel_change_restricted(2)=100*(wage_variance_vec_restricted(2)-wage_variance_vec_restricted(1))/(wage_variance_vec_restricted(1));
    wage_variance_vec_rel_change_restricted(1)=wage_variance_vec_restricted(1);
    welfare_variance_vec_rel_change_restricted(2)=100*(welfare_variance_vec_restricted(2)-welfare_variance_vec_restricted(1))/(welfare_variance_vec_restricted(1));
    welfare_variance_vec_rel_change_restricted(1)=welfare_variance_vec_restricted(1);
    u_rate_vec_rel_change_restricted(2)=100*(u_rate_vec_restricted(2)-u_rate_vec_restricted(1))/(u_rate_vec_restricted(1));
    u_rate_vec_rel_change_restricted(1)=u_rate_vec_restricted(1);
    avg_JF_vec_rel_change_restricted(2)=100*(avg_JF_vec_restricted(2)-avg_JF_vec_restricted(1))/(avg_JF_vec_restricted(1));
    avg_JF_vec_rel_change_restricted(1)=avg_JF_vec_restricted(1);
    avg_JS_vec_rel_change_restricted(2)=100*(avg_JS_vec_restricted(2)-avg_JS_vec_restricted(1))/(avg_JS_vec_restricted(1));
    avg_JS_vec_rel_change_restricted(1)=avg_JS_vec_restricted(1);
    theta_vec_rel_change_restricted(2)=100*(theta_vec_restricted(2)-theta_vec_restricted(1))/(theta_vec_restricted(1));
    theta_vec_rel_change_restricted(1)=theta_vec_restricted(1);
    
    fprintf('Decomposition')
    exper = [occ_pers_vec_restricted; occ_pers_vec_rel_change_restricted; ...
        %welfare_vec;
        welfare_vec_rel_change_restricted; output_rel_change_restricted;...
        sorting_adv_son_vec_restricted; sorting_pref_son_vec_restricted; ...
        sorting_adv_fat_vec_restricted; sorting_pref_fat_vec_restricted; ...
        output_per_work_vec_rel_change_restricted; wage_variance_vec_rel_change_restricted; ...
        welfare_variance_vec_rel_change_restricted; u_rate_vec_rel_change_restricted; ...
        avg_JF_vec_rel_change_restricted; avg_JS_vec_rel_change_restricted; ...
        theta_vec_rel_change_restricted]
    
    end
    
    if ncal==1
        exper_Spain=exper;
        save experiments/experiments_Spain.mat exper_Spain
    elseif ncal==2
        exper_US=exper;
        save experiments/experiments_US.mat exper_US
    elseif ncal==3
        exper_Spain_restricted=exper;
        save experiments/experiments_Spain_restricted.mat exper_Spain_restricted
    elseif ncal==4
        exper_US_restricted=exper;
        save experiments/experiments_US_restricted.mat exper_US_restricted
    end
    clear exper
end
clear
load results/calibration_results_Spain.mat
kappa_Spain=paramout;
load results/calibration_results_US.mat
kappa_US=paramout;

load experiments/experiments_Spain.mat exper_Spain
load experiments/experiments_US.mat exper_US
exper=[exper_US,exper_Spain];

%% Export to Latex:
rows={'Occupational Persistence';'($\Delta\%$ from baseline)';'Welfare ($\Delta\% $ from baseline)';'Output ($\Delta\% $ from baseline)';'Sorting along comparative advantage (sons)';'Sorting along preferences (sons)'; ...
    'Sorting along comparative advantage (fathers)';'Sorting along preferences (fathers)'; ...
    'Output per worker ($\Delta\% $ from baseline)';'Log Wage Variance ($\Delta\% $ from baseline)';'Welfare CV ($\Delta\% $ from baseline)';'Unemployment Rate ($\Delta\% $ from baseline)';...
    'Average UE Rate ($\Delta\% $ from baseline)'; 'Average EU Rate ($\Delta\% $ from baseline)'; 'Equilibrium Tightness'};
clear input
for j=1:size(exper,2)
    input.data(:,j)=exper(:,j);
end
T=table(exper,'RowNames',rows);
input.data = T;
input.dataFormat = {'%.3f'};
input.makeCompleteLatexDocument = 0;
input.tableBorders = 0;
input.tableSpace = 1;
input.tableCaption = 'Occupational Persistence Decomposition and Welfare Analysis. Numbers in parentheses are relative changes from baseline. Counterfactual Experiments: Columns (1)-(4) are under the baseline calibration and the US level of labor market frictions; Columns (5)-(8) are under the baseline calibration and Spanish level of labor market frictions.';

input.tableLabel='table_decomp_frictions';
input.headerText=sprintf(' & \\multicolumn{4}{c}{($\\kappa=%9.2f$)} & \\multicolumn{4}{c}{($\\kappa=%9.2f$)} \\\\ \\hline\\hline  & \\multicolumn{1}{c}{(1)} & \\multicolumn{1}{c}{(2)} & \\multicolumn{1}{c}{(3)} & \\multicolumn{1}{c}{(4)} & \\multicolumn{1}{c}{(5)} & \\multicolumn{1}{c}{(6)} & \\multicolumn{1}{c}{(7)} & \\multicolumn{1}{c}{(8)} \\\\            \\multicolumn{1}{l}{\\textbf{No parental net.}} ($\\xi=0$) & - & $\\checkmark$ & - & - & - & $\\checkmark$ & - & -  \\\\             \\multicolumn{1}{l}{\\textbf{No comp. adv. trans.}} ($\\rho_\\tau=1/O$)  & - & - & $\\checkmark$ & - & - & - & $\\checkmark$ & - \\\\         \\multicolumn{1}{l}{\\textbf{No pref. trans.}} ($\\rho_\\phi=1/O$)  & - & - & - & $\\checkmark$ & - & - & - & $\\checkmark$ \\\\            \\hline',kappa_US,kappa_Spain);

input.yesSpace = [1:length(exper)+1];
input.yesSpace(3)= 0; %switch off space after row 1 (it has to be "+2")
input.yesBrackets = zeros(1,length(exper)+1);
input.yesBrackets(3)= 3; % switch on where you want brackets
input.yesBrackets(4)= 4; % switch on where you want brackets
input.yesBrackets(5)= 5;
for j=10:13
    input.yesBrackets(j)= j; % switch on where you want brackets
end
for j=14:16
    input.yesBrackets(j)= j; % switch on where you want brackets
end
latex = latexTable(input);
% save LaTex code as file
fid=fopen('tables/table_exper_Spain_and_US.tex','w');
[nrows,ncols] = size(latex);
for row = 1:nrows
    fprintf(fid,'%s\n',latex{row,:});
end
fclose(fid);
