%FIXED GENERATION EQUILIBRIUM EXERCISES
clear


%% BASELINE
%load results/calibration_results_9occ.mat paramout
load results/calibration_results_3hc_9occ paramout %new results, 3hc, 9occ
baseline=paramout;
%Experiments one after the other
for nexp = [1 2 4 6 3 5 7]
    if nexp == 1, param=baseline; %baseline case
    elseif (nexp == 2) || (nexp == 3)
        %% COUNTERFACTUAL 1 (NO JF PREMIUM)
        param = baseline;
        param(3)=0;
    elseif (nexp == 4) || (nexp == 5)
        %% COUNTERFACTUAL 2 (NO COMP.ADV. TRANSMISSION)
        param = baseline;
        param(4)=1/n_occ;
    elseif (nexp == 6) || (nexp == 7)
        %% COUNTERFACTUAL 3 (NO PREF. TRANSMISSION)
        param = baseline;
        param(5)=1/n_occ;

    end    
    write_parameters(param,1)
    if nexp == 1
        model_sons(1);
        load 1/sons.mat
        theta_allpartial=theta;
        u_state_fix_gen=u_state_sons;
        e_state_fix_gen=e_state_sons;
    else
        if (nexp == 2) || (nexp == 4) || (nexp == 6)
            model_sons(1,theta_allpartial,true,u_state_fix_gen,e_state_fix_gen);
        else
            model_sons(1,theta_allpartial);
        end
    end
    
    compute_all_statistics(1);
    load('base_cal/statistics_exper.mat');
    
    %Here we define different variables for each experiment
    if nexp == 1
        sort_base= [share_adv_match_fat, 0, 0; share_pref_match_fat, 0, 0;...
            share_net; share_adv; share_pref; ...
            wage_mean_son, wage_mean_son_foll, wage_mean_son_move; ...
            u_rate, u_rate_foll, u_rate_move];
    end
    
    occ_pers_vec(nexp)=occ_pers;
    welfare_vec(nexp)=welfare;
    total_output_vec(nexp)=total_output;
    sorting_adv_son_vec(nexp)=sorting_adv;
    sorting_pref_son_vec(nexp)=sorting_pref;
    sorting_adv_fat_vec(nexp)=sorting_adv_fat;
    sorting_pref_fat_vec(nexp)=sorting_pref_fat;
    output_per_work_vec(nexp)=output_per_work;
    wage_variance_vec(nexp)=wage_variance;
    welfare_variance_vec(nexp)=CV_welfare;
    u_rate_vec(nexp)=u_rate;
    avg_JF_vec(nexp)=avg_JF;
    avg_JS_vec(nexp)=avg_JS;
    theta_vec(nexp)=max(theta);
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

occ_pers_vec_rel_change(2:7)= 100*(occ_pers_vec(2:7)-occ_pers_vec(1))/(occ_pers_vec(1)-1);
welfare_vec_rel_change(2:7)= 100*(welfare_vec(2:7)-welfare_vec(1))/(welfare_vec(1));
output_rel_change(2:7)=(total_output_vec(2:7)-total_output_vec(1))/total_output_vec(1);
output_per_work_vec_rel_change(2:7)=(output_per_work_vec(2:7))/(output_per_work_vec(1));
output_per_work_vec_rel_change(1)=1;  
wage_variance_vec_rel_change(2:7)=100*(wage_variance_vec(2:7)-wage_variance_vec(1))/(wage_variance_vec(1));
wage_variance_vec_rel_change(1)=wage_variance_vec(1);
welfare_variance_vec_rel_change(2:7)=100*(welfare_variance_vec(2:7)-welfare_variance_vec(1))/(welfare_variance_vec(1));
welfare_variance_vec_rel_change(1)=welfare_variance_vec(1);
u_rate_vec_rel_change(2:7)=100*(u_rate_vec(2:7)-u_rate_vec(1))/(u_rate_vec(1));
u_rate_vec_rel_change(1)=u_rate_vec(1);
avg_JF_vec_rel_change(2:7)=100*(avg_JF_vec(2:7)-avg_JF_vec(1))/(avg_JF_vec(1));
avg_JF_vec_rel_change(1)=avg_JF_vec(1);
avg_JS_vec_rel_change(2:7)=100*(avg_JS_vec(2:7)-avg_JS_vec(1))/(avg_JS_vec(1));
avg_JS_vec_rel_change(1)=avg_JS_vec(1);
theta_vec_rel_change(2:7)=100*(theta_vec(2:7)-theta_vec(1))/(theta_vec(1));
theta_vec_rel_change(1)=theta_vec(1);

fprintf('Decomposition: fixed generations')
exper = [occ_pers_vec; occ_pers_vec_rel_change; ...
 %welfare_vec;
 welfare_vec_rel_change; output_rel_change; ...
 sorting_adv_son_vec; sorting_pref_son_vec; ...
 sorting_adv_fat_vec; sorting_pref_fat_vec; ...
 output_per_work_vec_rel_change; wage_variance_vec_rel_change; ...
 welfare_variance_vec_rel_change; u_rate_vec_rel_change; ...
 avg_JF_vec_rel_change; avg_JS_vec_rel_change; ...
 theta_vec_rel_change]

rows={'Occupational Persistence';'($\Delta\%$ from baseline)';'Welfare ($\Delta\% $ from baseline)';'Output ($\Delta\% $ from baseline)';'Sorting along comparative advantage (sons)';'Sorting along preferences (sons)'; ...
    'Sorting along comparative advantage (fathers)';'Sorting along preferences (fathers)'; ...
    'Output per worker (=1 in baseline)';'Log Wage Variance ($\Delta\% $ from baseline)';'Welfare CV ($\Delta\% $ from baseline)';'Unemployment Rate ($\Delta\% $ from baseline)';...
    'Average UE Rate ($\Delta\% $ from baseline)'; 'Average EU Rate ($\Delta\% $ from baseline)'; 'Equilibrium Tightness'};
clear input
for j=1:size(exper,2)
   input.data(:,j)=exper(:,j); 
end
T=table(exper,'RowNames',rows);
input.data = T; 
input.dataFormat = {'%.3f'};
input.makeCompleteLatexDocument = 0;
input.numTable = 2;   % number of table (for this file)
input.tableBorders = 0;
input.tableSpace = 1;
input.headerText='\hline\hline  & \multicolumn{1}{c}{(1)} & \multicolumn{1}{c}{(2)} & \multicolumn{1}{c}{(3)} & \multicolumn{1}{c}{(4)} & \multicolumn{1}{c}{(5)} & \multicolumn{1}{c}{(6)} & \multicolumn{1}{c}{(7)} \\  \multicolumn{1}{l}{\textbf{No parental net.} \hspace{2.9cm}($\xi=0$)} & - & $\checkmark$ & $\checkmark$ & - & - & - & - \\ \multicolumn{1}{l}{\textbf{No comp. adv. trans.}} ($\rho_\tau=1/O$)  & - & - & $\checkmark$ & $\checkmark$ & - & - & -  \\ \multicolumn{1}{l}{\textbf{No pref. trans.}} ($\rho_\phi=1/O$)  & - & - & - & $\checkmark$ & $\checkmark$ & - & - \\  \hline';
input.tableCaption = 'Occupational Persistence Decomposition and Welfare Analysis in partial equilibrium, when the starting generation is fixed.';
input.tableLabel='table_decomp_fix_gen';
input.yesSpace = [1:length(exper)+1];
input.yesSpace(3)= 0; %switch off space after row 1 (it has to be "+2")
input.yesBrackets = zeros(1,length(exper)+1);

input.yesBrackets(3)= 3; % switch on where you want brackets
input.yesBrackets(4)= 4; % switch on where you want brackets
input.yesBrackets(5)= 5;
for j=11:16
   input.yesBrackets(j)= j; % switch on where you want brackets
end
latex = latexTable(input);
% save LaTex code as file
fid=fopen('tables/table_exper_fix_gen.tex','w');
[nrows,ncols] = size(latex);
for row = 1:nrows
    fprintf(fid,'%s\n',latex{row,:});
end
fclose(fid);
