function res = exper_unemp_benef(type_experiment)

if nargin < 1, type_experiment='baseline'; end
%% BASELINE
% baseline=[5.240064771  0.003045990  0.406403728  0.499648455  0.720621782  0.586094151 ...
%  0.813971249  1.014349489  0.762106234  0.750917723  0.952840217  0.235468324 ]; %TARGETS HIT! loss 0.0028, 3 occ

%baseline=[5.366174564   0.003043529   0.368786302   0.359564554   0.482934603   0.422945462 ...
%  0.820181746   1.028762271   0.932425669   0.756353740   0.997813267   0.205778892 ]; %loss 0.00325, 4 occupations

if strcmp(type_experiment,'baseline')
    %load calibration_results_9occ.mat paramout %old version, n_hc=2, occ=9
    load results/calibration_results_3hc_9occ paramout %new results, 3hc, 9occ
    baseline=paramout;
elseif strcmp(type_experiment,'restricted')
    %load calibration_results_9occ_restricted.mat paramout %loads restricted calibration
    load results/calibration_results_3hc_9occ_restricted.mat paramout
    baseline(1:2)=paramout(1:2);
    baseline(3)=0;
    baseline(4)=paramout(3);
    baseline(5)=1/9;
    baseline(6:12)=paramout(4:10);
end

%Experiments one after the other
for nexp = 1:5
    param=baseline;
    
    if strcmp(type_experiment,'baseline')
        load results/b_policy_results_baseline.mat  b_policy tau_policy   %loads U insurance values with tax for gov. BC
    elseif strcmp(type_experiment,'restricted')
        load results/b_policy_results_restricted.mat  b_policy tau_policy
    end
    %NOTICE: they must be reloaded every time because they have the same
    %name as the one specified in write_parameters_SPARSE
    if nexp == 1, write_parameters(param,1,0,0);
    else, write_parameters(param,1,b_policy(nexp-1),tau_policy(nexp-1));
    end  
    model_sons(1);
    
    compute_all_statistics(1);
    load('base_cal/statistics_exper.mat');
    
    %Here it defines different variables for each experiment
    occ_pers_vec(nexp)=occ_pers;
    welfare_vec(nexp)=welfare;
    total_output_vec(nexp)=total_output;
    welfare_followers(nexp)=welfare_followers;
    welfare_movers(nexp)=welfare_movers;
    sorting_adv_son_vec(nexp)=sorting_adv;
    sorting_pref_son_vec(nexp)=sorting_pref;
    sorting_adv_fat_vec(nexp)=sorting_adv_fat;
    sorting_pref_fat_vec(nexp)=sorting_pref_fat;
    output_per_work_vec(nexp)=output_per_work;
    wage_variance_vec(nexp)=wage_variance;
    welfare_variance_vec(nexp)=CV_welfare;
    u_rate_vec(nexp)=u_rate;
    avg_JF_vec(nexp)=avg_JF;
    avg_JS_vec(nexp)=avg_JS;
    theta_vec(nexp)=max(theta);
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

occ_pers_vec_rel_change(2:5)= 100*(occ_pers_vec(2:5)-occ_pers_vec(1))/(occ_pers_vec(1)-1);
welfare_vec_rel_change(2:5)= 100*(welfare_vec(2:5)-welfare_vec(1))/(welfare_vec(1));
output_rel_change(2:5)=(total_output_vec(2:5)-total_output_vec(1))/total_output_vec(1);
occ_pers_vec_rel_change(1)=NaN;
welfare_vec_rel_change(1)=NaN;
output_per_work_vec_rel_change(2:5)=(output_per_work_vec(2:5))/(output_per_work_vec(1));
output_per_work_vec_rel_change(1)=1;
wage_variance_vec_rel_change(2:5)=100*(wage_variance_vec(2:5)-wage_variance_vec(1))/(wage_variance_vec(1));
wage_variance_vec_rel_change(1)=wage_variance_vec(1);
welfare_variance_vec_rel_change(2:5)=100*(welfare_variance_vec(2:5)-welfare_variance_vec(1))/(welfare_variance_vec(1));
welfare_variance_vec_rel_change(1)=welfare_variance_vec(1);
u_rate_vec_rel_change(2:5)=100*(u_rate_vec(2:5)-u_rate_vec(1))/(u_rate_vec(1));
u_rate_vec_rel_change(1)=u_rate_vec(1);
avg_JF_vec_rel_change(2:5)=100*(avg_JF_vec(2:5)-avg_JF_vec(1))/(avg_JF_vec(1));
avg_JF_vec_rel_change(1)=avg_JF_vec(1);
avg_JS_vec_rel_change(2:5)=100*(avg_JS_vec(2:5)-avg_JS_vec(1))/(avg_JS_vec(1));
avg_JS_vec_rel_change(1)=avg_JS_vec(1);
theta_vec_rel_change(2:5)=100*(theta_vec(2:5)-theta_vec(1))/(theta_vec(1));
theta_vec_rel_change(1)=theta_vec(1);

fprintf('Exercises')
exper = [occ_pers_vec; occ_pers_vec_rel_change; ...
 %welfare_vec;
 welfare_vec_rel_change; output_rel_change; ...
 sorting_adv_son_vec; sorting_pref_son_vec; ...
 sorting_adv_fat_vec; sorting_pref_fat_vec; ...
 output_per_work_vec_rel_change; wage_variance_vec_rel_change; ...
 welfare_variance_vec_rel_change; u_rate_vec_rel_change; ...
 avg_JF_vec_rel_change; avg_JS_vec_rel_change; ...
 theta_vec_rel_change]


%% Export to Latex:
rows={'Occupational Persistence';'($\Delta\%$ from baseline)';'Welfare ($\Delta\% $ from baseline)';'Output ($\Delta\% $ from baseline)';'Sorting along comparative advantage (sons)';'Sorting along preferences (sons)'; ...
    'Sorting along comparative advantage (fathers)';'Sorting along preferences (fathers)'; ...
    'Output per worker (=1 in baseline)';'Log Wage Variance ($\Delta\% $ from baseline)';'Welfare CV ($\Delta\% $ from baseline)';'Unemployment Rate ($\Delta\% $ from baseline)';...
    'Average UE Rate ($\Delta\% $ from baseline)'; 'Average EU Rate ($\Delta\% $ from baseline)'; 'Equilibrium Tightness'};
clear input
for j=1:size(exper,2)
   input.data(:,j)=exper(:,j); 
end
T=table(exper,'RowNames',rows);
input.data = T; 
input.dataFormat = '%.3f';
input.makeCompleteLatexDocument = 0;
input.tableBorders = 0;
input.tableSpace = 1;
input.dataFormat = {'%.3f'};
input.tableLabel = 'table_unemp_benef';
input.tableCaption = 'Policy Experiment: effect of changes in unemployment benefits.';
input.yesSpace = [1:length(exper)+1];
input.yesSpace(3)= 0; %switch off space after row 1 (it has to be "+2")
input.yesBrackets = zeros(1,length(exper)+1);
input.yesBrackets(3)= 3; % switch on where you want brackets
input.yesBrackets(4)= 4; % switch on where you want brackets
input.yesBrackets(5)= 5; % switch on where you want brackets
for j=11:16
   input.yesBrackets(j)= j; % switch on where you want brackets
end
latex = latexTable(input);
% save LaTex code as file
if strcmp(type_experiment,'baseline')
    fid=fopen('tables/table_exper_unemp_benef.tex','w');
elseif strcmp(type_experiment,'restricted')
    fid=fopen('tables/table_exper_unemp_benef_restricted.tex','w');
end
[nrows,ncols] = size(latex);
for row = 1:nrows
    fprintf(fid,'%s\n',latex{row,:});
end
fclose(fid);

end
