function [res_k,mom] = table_robustness_experiments(alreadycomputed)

if nargin < 1, alreadycomputed=0; end

if alreadycomputed == 0
    
    load results/calibration_results_3hc_9occ.mat paramout
    %Build a table with changes in all moments when all parameters change
    
    params_totry=zeros(12,12);
    res_k=zeros(12,1);
    mom=zeros(12,12);
    
    baseline=paramout;
    for kk22=1:13
        par_now=baseline;
        if kk22>1
            par_now(kk22-1)=par_now(kk22-1)*(1.05); %manipulate parameter
        end
        for nexp = 1:4
            if nexp == 1, param=par_now; %baseline case
            elseif nexp == 2
                %% COUNTERFACTUAL 1 (NO JF PREMIUM)
                param = par_now;
                param(3)=0;
            elseif nexp == 3
                %% COUNTERFACTUAL 2 (NO COMP.ADV. TRANSMISSION)
                param = par_now;
                param(4)=1/n_occ;
            elseif nexp == 4
                %% COUNTERFACTUAL 3 (NO PREF. TRANSMISSION)
                param = par_now;
                param(5)=1/n_occ;
            end
            
            write_parameters(param)
            model_sons;
            compute_all_statistics;
            load('base_cal/statistics_exper.mat');
            
            occ_pers_vec(nexp,kk22)=occ_pers;
            welfare_vec(nexp,kk22)=welfare;
            total_output_vec(nexp,kk22)=total_output;
            sorting_adv_son_vec(nexp,kk22)=sorting_adv;
            sorting_pref_son_vec(nexp,kk22)=sorting_pref;
            sorting_adv_fat_vec(nexp,kk22)=sorting_adv_fat;
            sorting_pref_fat_vec(nexp,kk22)=sorting_pref_fat;
            output_per_work_vec(nexp,kk22)=output_per_work;
            wage_variance_vec(nexp,kk22)=wage_variance;
            welfare_variance_vec(nexp,kk22)=CV_welfare;
            u_rate_vec(nexp,kk22)=u_rate;
            avg_JF_vec(nexp,kk22)=avg_JF;
            avg_JS_vec(nexp,kk22)=avg_JS;
            theta_vec(nexp,kk22)=max(theta);
        end
    end

    save results/table_robustness_experiments.mat
end

%Load, plot and table
load results/table_robustness_experiments.mat

occ_pers_vec=(occ_pers_vec-occ_pers_vec(1,:))./(occ_pers_vec(1,:)-1);
total_output_vec=(total_output_vec-total_output_vec(1,:))./total_output_vec(1,:);
output_per_work_vec=(output_per_work_vec-output_per_work_vec(1,:))./output_per_work_vec(1,:);
welfare_vec=(welfare_vec-welfare_vec(1,:))./welfare_vec(1,:);
u_rate_vec=(u_rate_vec-u_rate_vec(1,:))./u_rate_vec(1,:);


variable_now=["occpers","output","outputpw","unemp","welfare_vec"];

%FIGURES
for nexp=2:4
    
    for kkk=1:5 
        fig_id2=figure('Color','white');
        if kkk==1
            bar((1:14)',[occ_pers_vec(nexp,1) 0 occ_pers_vec(nexp,2:end)]','BaseValue',0);
        elseif kkk==2
            bar((1:14)',[total_output_vec(nexp,1) 0 total_output_vec(nexp,2:end)]','BaseValue',0);
        elseif kkk==3
            bar((1:14)',[output_per_work_vec(nexp,1) 0 output_per_work_vec(nexp,2:end)]','BaseValue',0);
        elseif kkk==4
            bar((1:14)',[u_rate_vec(nexp,1) 0 u_rate_vec(nexp,2:end)]','BaseValue',0);
        elseif kkk==5
            bar((1:14)',[welfare_vec(nexp,1) 0 welfare_vec(nexp,2:end)]','BaseValue',0);
        end

        ax=gca;
        ax.TickLabelInterpreter='latex';
        ax.TickLength=[0 0];
        xticklabels({'Baseline','','$\kappa$','$\delta$','$\xi$','$\rho_\phi$','$\rho_\tau$','$\sigma_\epsilon$',...
            '$\hat{\phi}$','$\hat{\tau}$','$\hat{n}$','$b$','$p_h^-$','$p_n^-$'});
        ylabel('Relative change from baseline','Interpreter','latex');
        saveas(fig_id2,sprintf('figures/experiment_%g_%s.eps',nexp,variable_now(kkk)),'eps');
    end
end

%MEGA-TABLE
%This line is for my folder name
fileid2=fopen('tables/table_robustness_parameters.tex','w+');
fprintf(fileid2,'  \\begin{tabular}{l c c c c c c c c c c c c c c} \\hline\\hline   \n');
fprintf(fileid2,' & Baseline && $\\kappa$ & $\\delta$ & $\\xi$ & $\\rho_\\phi$ & $\\rho_\\tau$ & $\\sigma_\\epsilon$ & $\\hat{\\phi}$ & $\\hat{\\tau}$ & $\\hat{n}$ & $b$ & $p_h^-$ & $p_n^-$ \\\\ \\hline \n');
fprintf(fileid2,' [1em] \\\\ \n');
for nexp = 2:4
    if nexp == 2
        fprintf(fileid2,' & \\multicolumn{14}{c}{Shutting down parental networks: $\\xi = 0$} \\\\ \n');
    elseif nexp == 3
        fprintf(fileid2,' & \\multicolumn{14}{c}{Shutting down tranmission of advantage: $\\rho_\\tau = 0$} \\\\ \n');
    elseif nexp == 4
        fprintf(fileid2,' & \\multicolumn{14}{c}{Shutting down transmission of preferences: $\\rho_\\phi = 0$} \\\\ \n');
    end
    for kkk = 1:5
        if kkk==1, fprintf(fileid2,' Occupational persistence & %3.2f & ',occ_pers_vec(nexp,1)*100);
        elseif kkk==2, fprintf(fileid2,' Total output  & %3.2f &',total_output_vec(nexp,1)*100);
        elseif kkk==3, fprintf(fileid2,' Output per worker  & %3.2f &',output_per_work_vec(nexp,1)*100);
        elseif kkk==4, fprintf(fileid2,' Unemployment rate  & %3.2f &',u_rate_vec(nexp,1)*100);
        elseif kkk==5, fprintf(fileid2,' Welfare  & %3.2f &',welfare_vec(nexp,1)*100);
        end
        for xxx=2:13
            if kkk==1, fprintf(fileid2,' & %3.2f ',occ_pers_vec(nexp,xxx)*100);
            elseif kkk==2, fprintf(fileid2,' & %3.2f ',total_output_vec(nexp,xxx)*100);
            elseif kkk==3, fprintf(fileid2,' & %3.2f ',output_per_work_vec(nexp,xxx)*100);
            elseif kkk==4, fprintf(fileid2,' & %3.2f ',u_rate_vec(nexp,xxx)*100);
            elseif kkk==5, fprintf(fileid2,' & %3.2f ',welfare_vec(nexp,xxx)*100);
            end
        end
        fprintf(fileid2,' \\\\ \n');
    end
    fprintf(fileid2,' [1em] \n');
end
fprintf(fileid2,' \\hline\\hline \n');
fprintf(fileid2,'  \\end{tabular}  \n');
fclose(fileid2);

end