function res  = write_parameters( param, outputfolder,b_policy,tau_policy  )
%This file writes parameters in a file for use later
%fprintf(' %9.9f \n',param);
if nargin<1
load base_cal/parameters_model.mat param  
end
load base_cal/targets.mat targets

if nargin < 3
    b_policy=0;
    tau_policy=0;
end

if numel(param) < 13, param(13)=1/60; end %default HC accumulation
if numel(param) < 14, param(14)=1.1980; end %default HC premium
if numel(param) < 15, param(15)=1.2990; end %default HC(2) premium

%param(14)=1.26; %override
%param(15)=1.26; %override

%param(14)=0.077575;
%param(15)=0.105300; %returns with controls!!! (lower)

xi=param(3);      %Added search efficiency from father employed
eta=0; %1-xi;         %Fraction of own network not substituted by father's
b=param(10)+b_policy;       %Value of unemployment
zeta_par=0.00416;%Probability of death  (average life length= 20 + 20)
disc=0.9966; %Discount factor
delta=param(2);  %Exogenous separation rate
kappa=param(1);   %Vacancy cost
beta_par=0.5;    %Bargaining power of workers
A=0.1;       %Scale of matching function
gamma=0.5;   %Elastiticy of unemployment in Matching Function
piecerate=0.7;  

sigma_shocks=param(6);

%Transmission Parameters
pers_pref=param(5);
pers_adv=param(4);

adj_weight=0.1;


toll=10^(-9);           %Tolerance for convergence of V functions
toll_tightness=(10^(-8)); %Tolerance for convergence of market tightness

%speedup: lower convergence values FOR NELDER-MEAD, RESET TO ABOVE FOR FSOLVE
toll=10^(-8);
toll_tightness=(10^(-6));

upperbound_probabilities=0.999;
lowerbound_probabilities=1-upperbound_probabilities;

lambda=disc*(1-zeta_par);   %Final discount factor

% q_fun=@(x)(1 - exp(-(1./x)));
% q_inverse=@(x)-(1./(log(1 - x)));
% jf_function=@(x)x.*(1 - exp(-(1./x)));     %Anonymous functions for JF and Q^(-1) = Urn-ball matching scheme

q_fun=@(x)A.*(1./x).^(gamma);
q_inverse=@(x)(A./x).^(1/gamma);
jf_function=@(x) A.*x.^(1-gamma);     %Anonymous functions for JF and Q^(-1) = Cobb-Douglas
jf_inverse=@(x) (x/A).^(1/(1-gamma));

min_theta=q_inverse(1);
max_theta=jf_inverse(1);

%Transition Probabilities
hc_gain=param(13);   %Human capital Accumulation and Depreciation
hc_lose=param(11);
net_gain=(0.008)/(0.1251*param(9)*12);   %Networks accumulation and depreciation
net_lose=param(12);

%State Space definition
n_pos=5;                   % Number of positions
n_hc=3;                    % Levels of skills
n_net=2;                   % Levels of networks
n_occ=9;                   % KEEP FOR NOW!
n_es=2;                    % Number of Employment Statuses (Employed, Unemployed)

% Transition of positions (for occupational choice of fathers)
pos_trans_occ=zeros(n_pos,n_occ);
pos_trans_occ(1,:)=[1 4*ones(1,n_occ-1)];
pos_trans_occ(2,:)=[2 3 5*ones(1,n_occ-2)];
pos_trans_occ(3,:)=[3 2 5*ones(1,n_occ-2)];
pos_trans_occ(4,:)=[4 1 4*ones(1,n_occ-2)];
pos_trans_occ(5,:)=[5 2 3 5*ones(1,n_occ-3)];


statesize_fat=n_pos*(n_hc)*(n_net);
%Matrices of indices - will be used later
[j1_ind_fat, j2_ind_fat, j3_ind_fat]=ind2sub([n_pos n_hc n_net],1:statesize_fat);
matrix_indexes_father=[j1_ind_fat' j2_ind_fat' j3_ind_fat'];


fprintf('State size of fathers equal to %g \n',statesize_fat);
 if isfile(sprintf('base_cal/state_sons_built_nhc%g.mat',n_hc)) == 0
      fprintf('Building state of sons... \n')
      build_state_sons(n_pos,n_hc,n_net,n_es,n_occ,matrix_indexes_father);
 end


load(sprintf('base_cal/state_sons_built_nhc%g.mat',n_hc),'matrix_indexes_son','wheretolook_son','pos','sum_pos');
statesize_son=size(matrix_indexes_son,1);
fprintf('State size of sons equal to %g \n',statesize_son);
   
if n_hc == 2, hcvec=[1; param(14)];     %hcvec=[1; 1.02; 1.04];  %hcvec=[1; 1.02];
elseif n_hc == 3, hcvec=[1; param(14); param(15)];   %new extended vector
end

prefvec=zeros(1,2);
for i=2:numel(prefvec)
   prefvec(i)= 0 + (i-1)*(param(7))/(numel(prefvec)-1);
end
advvec=ones(1,2);
for i=2:numel(advvec)
   advvec(i)= 1 + (i-1)*(param(8))/(numel(advvec)-1);
end
%prefvec=[0; 0+param(7)];             OLD one
%advvec=[1; (1+param(8))];            OLD one
netvec=[1; 1*(1+param(9))];    %netvec=[1; 1.06; 1.12]; %netvec=[1; 1.02];


%Here the code already prepares transition matrices
occ_trans_E=eye(n_occ);       %For now, the probability of transition from occ i to j = 1 on diagonal
occ_trans_U=eye(n_occ);


hc_trans_E=sparse(zeros(n_hc,n_hc));   %Transition of human capital when Employed
for j=1:1:n_hc-1
    hc_trans_E(j,j)=1-hc_gain;
    hc_trans_E(j,j+1)=hc_gain;
end
hc_trans_E(n_hc,n_hc)=1;

hc_trans_U=sparse(zeros(n_hc,n_hc));   %Transition of human capital when Unemployed
for j=2:1:n_hc
    hc_trans_U(j,j)=1-hc_lose;
    hc_trans_U(j,j-1)=hc_lose;
end
hc_trans_U(1,1)=1;

%Perfectly persistent transitions
pos_trans_E=sparse(eye(n_pos));              %Transition of Positions when Employed, for now perfectly persistent
pos_trans_U=sparse(eye(n_pos));              %Transition of Preferences when Unemployed, for now perfectly persistent

net_trans_E=sparse(zeros(n_net,n_net));   %Transition of Networks when Employed
for j=1:1:n_net-1
    net_trans_E(j,j)=1-net_gain;
    net_trans_E(j,j+1)=net_gain;
end
net_trans_E(n_net,n_net)=1;

net_trans_U=sparse(zeros(n_net,n_net));   %Transition of Networks when Unemployed
for j=2:1:n_net
    net_trans_U(j,j)=1-net_lose;
    net_trans_U(j,j-1)=net_lose;
end
net_trans_U(1,1)=1;


    % Matrix of indexes for sons already generated

% Link sons to the fathers who they will be (for value function and distributions):
whichfather=zeros(statesize_son,1);
%new more efficient method for the computation of whichfather
for state=1:statesize_son
    controlnow=(matrix_indexes_father(:,1)==matrix_indexes_son(state,1)).*(matrix_indexes_father(:,2)==matrix_indexes_son(state,13)).* ...
        (matrix_indexes_father(:,3)==matrix_indexes_son(state,14));
    whichfather(state)=find(controlnow);
end

%Useful stuff for later
indicator_fat=repmat(logical(eye(n_pos)),(statesize_fat/n_pos),(statesize_fat/n_pos)); %using logical to save RAM

%Vectors of FATHERS
% NEW: MORE GENERAL!!! Productivity of father, state by state
productivity_temp=ones(n_pos,n_hc,n_net);
%Networks of fathers
network_temp=ones(n_pos,n_hc,n_net).*netvec(1);
%Preferences of Father
preferences_temp=ones(n_pos,n_hc,n_net).*prefvec(1);
for jj=1:n_hc
   productivity_temp(:,jj,:)=productivity_temp(:,jj,:).*hcvec(jj); 
end
for jj=1:n_net
   network_temp(:,:,jj)=network_temp(:,:,jj).*netvec(jj); 
end

preferences_temp(1,:,:)=prefvec(2);
preferences_temp(3,:,:)=prefvec(2);

productivity_temp(1,:,:)=productivity_temp(1,:,:)*advvec(2);
productivity_temp(2,:,:)=productivity_temp(2,:,:)*advvec(2);

productivity_father=reshape(productivity_temp,statesize_fat,1) - tau_policy;
pref_father=reshape(preferences_temp,statesize_fat,1);
net_father=reshape(network_temp,statesize_fat,1);

%Vectors of SONS
productivity_son=ones(statesize_son,1);
pref_son=ones(statesize_son,1)*prefvec(1);
net_son=ones(statesize_son,1)*netvec(1);
net_son2=net_son;

%Extend to more HC points
for kk=2:n_hc
    productivity_son=productivity_son.*(1+(hcvec(kk)-1).*(matrix_indexes_son(:,13)==kk));
end

%productivity_son=productivity_son.*(1+(hcvec(2)-1)*(matrix_indexes_son(:,13)==2));
%OLD VERSION OF NETWORKS: FATHER'S NETWORKS ARE ON TOP OF YOURS
% net_son=net_son.*(1+(netvec(2)-1).*(matrix_indexes_son(:,14)==2)) + ...
%     xi.*(matrix_indexes_son(:,12)==2).*(matrix_indexes_son(:,2)==1).* ...
%     (1 + (netvec(2)-1).*(matrix_indexes_father(matrix_indexes_son(:,3),3)==2));
%NEW VERSION OF NETWORKS: FATHER'S NETWORKS ARE SUBSTITUTES
%ASSUMPTION: IF FATHER'S NETWORK ACTIVE, OWN NETWORK LESS IMPORTANT (eta fraction remains available - to be calibrated)
mover=(matrix_indexes_son(:,2)==0);
follower_father_emp=(matrix_indexes_son(:,2)==1 & matrix_indexes_son(:,12)==2);
follower_father_unemp=(matrix_indexes_son(:,2)==1 & matrix_indexes_son(:,12)==1);
highnetwork=(netvec(2)-1).*(matrix_indexes_son(:,14)==2);
%net_son=mover.*net_son.*(1+highnetwork) + ...
%    follower_father_emp.*net_son.*(1 + xi.*(1+((netvec(2)-1).*(matrix_indexes_father(matrix_indexes_son(:,3),3)==2))) + eta.*highnetwork) + ...
%    follower_father_unemp.*net_son.*(1+highnetwork);

%REPLACED WITH NEW ASSUMPTION: use the best of the two networks
%eta=1;
net_son=mover.*net_son.*(1+highnetwork) + ...
    follower_father_emp.*net_son.* max((1 + xi.*(1+((netvec(2)-1).*(matrix_indexes_father(matrix_indexes_son(:,3),3)==2))) + eta.*highnetwork),(1+highnetwork)) + ...
    follower_father_unemp.*net_son.*(1+highnetwork);
%CHECKS! THESE ALLOWED TO DISCOVER THE PROBLEM WITH THE STATE
%[min(sum(mover+follower_father_emp+follower_father_unemp,2))]
%[unique(matrix_indexes_son(:,10))]
%[unique(matrix_indexes_son(:,11))]
%[unique(matrix_indexes_son(:,12))]
%[unique(matrix_indexes_son(:,13))]
%[unique(matrix_indexes_son(:,14))]
%pause
%[(1:statesize_son)' net_son net_son2]
%pause


%net_son=(matrix_indexes_son(:,2)==0).*net_son2.*(1+(netvec(2)-1).*(matrix_indexes_son(:,14)==2)) + ... %mover
%    (matrix_indexes_son(:,2)==1).*net_son2.*(((matrix_indexes_son(:,12)==2).* ...
%    (1 + (xi.*(netvec(2)-1) + eta.*(netvec(2)-1).*(matrix_indexes_son(:,14)==2)).*(matrix_indexes_father(matrix_indexes_son(:,3),3)==2))) + (((eta).*(netvec(2)-1))));
%[mean(net_son(matrix_indexes_son(:,2)==0)) mean(net_son(matrix_indexes_son(:,2)==1))]
%[mean(net_son2(matrix_indexes_son(:,2)==0)) mean(net_son2(matrix_indexes_son(:,2)==1))]
%[mean(net_son(matrix_indexes_son(:,2)==0 & matrix_indexes_son(:,14)==2)) mean(net_son(matrix_indexes_son(:,2)==1 & matrix_indexes_son(:,14)==2))]
%[mean(net_son2(matrix_indexes_son(:,2)==0 & matrix_indexes_son(:,14)==2)) mean(net_son2(matrix_indexes_son(:,2)==1 & matrix_indexes_son(:,14)==2))]
%[mean(net_son(follower_father_emp)) mean(net_son(follower_father_unemp)) mean(net_son(mover))]
%[mean(net_son(follower_father_emp & matrix_indexes_son(:,14)==1)) mean(net_son(follower_father_emp & matrix_indexes_son(:,14)==2))]

pref_son=pref_son+(prefvec(2))*(pos(matrix_indexes_son(:,1),2)==1); 
productivity_son=productivity_son.*(1 + (advvec(2)-1)*(pos(matrix_indexes_son(:,1),1)==1)) - tau_policy; 


%%%%%%%%%%% CHECK THIS ALSO!!!! %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Transition matrix from sons to fathers
%whichsonnow=[1:statesize_son]';
%whichfather_later=[1:statesize_fat];
%transit_to_father_temp=repmat(whichfather,1,statesize_fat);
%transit_to_father_temp2=repmat(whichfather_later,statesize_son,1);
%transit_to_father=(transit_to_father_temp==transit_to_father_temp2);

%Rewriting it so that it takes way less memory and time
transit_to_father=sparse(statesize_son,statesize_fat);
for kk=1:statesize_fat
    transit_to_father(:,kk)=(whichfather==kk);
end


%Clears useless stuff so that it is NOT saved (some are enormous matrices that are never used anymore)
clear controlnow productivity_temp preferences_temp network_temp whichsonnow whichfather_later
%Saving parameters  
if nargin < 2, save base_cal/parameters_model.mat 
else saveto_string=sprintf('%g\\parameters_model.mat',outputfolder); save(saveto_string); end
end